@@ -1,6 +1,7 @@
 package deployment
 
 import (
+	"context"
 	"fmt"
 
 	// kube
@@ -15,17 +16,11 @@ import (
 	// openshift
 	configv1 "github.com/openshift/api/config/v1"
 	operatorv1 "github.com/openshift/api/operator/v1"
-	routev1 "github.com/openshift/api/route/v1"
 	"github.com/openshift/console-operator/pkg/api"
 	"github.com/openshift/console-operator/pkg/console/subresource/util"
 )
 
 const (
-	consolePortName        = "https"
-	consolePort            = 443
-	consoleTargetPort      = 8443
-	publicURLName          = "BRIDGE_DEVELOPER_CONSOLE_URL"
-	ConsoleServingCertName = "console-serving-cert"
 	ConsoleOauthConfigName = "console-oauth-config"
 	ConsoleReplicas        = 2
 )
@@ -63,7 +58,7 @@ type volumeConfig struct {
 	mappedKeys  map[string]string
 }
 
-func DefaultDeployment(operatorConfig *operatorv1.Console, cm *corev1.ConfigMap, serviceCAConfigMap *corev1.ConfigMap, defaultIngressCertConfigMap *corev1.ConfigMap, trustedCAConfigMap *corev1.ConfigMap, sec *corev1.Secret, rt *routev1.Route, proxyConfig *configv1.Proxy, canMountCustomLogo bool) *appsv1.Deployment {
+func DefaultDeployment(operatorConfig *operatorv1.Console, cm *corev1.ConfigMap, serviceCAConfigMap *corev1.ConfigMap, defaultIngressCertConfigMap *corev1.ConfigMap, trustedCAConfigMap *corev1.ConfigMap, sec *corev1.Secret, proxyConfig *configv1.Proxy, canMountCustomLogo bool) *appsv1.Deployment {
 	labels := util.LabelsForConsole()
 	meta := util.SharedMeta()
 	meta.Labels = labels
@@ -77,8 +72,7 @@ func DefaultDeployment(operatorConfig *operatorv1.Console, cm *corev1.ConfigMap,
 		consoleImageAnnotation:                               util.GetImageEnv(),
 	}
 	// Set any annotations as needed so that `ApplyDeployment` rolls out a
-	// new version when they change. `ApplyDeployment` doesn't compare that
-	// pod template, but it does check deployment annotations.
+	// new version when they change.
 	meta.Annotations = annotations
 	replicas := int32(ConsoleReplicas)
 	gracePeriod := int64(40)
@@ -171,8 +165,8 @@ func Stub() *appsv1.Deployment {
 	return dep
 }
 
-func LogDeploymentAnnotationChanges(client appsclientv1.DeploymentsGetter, updated *appsv1.Deployment) {
-	existing, err := client.Deployments(updated.Namespace).Get(updated.Name, metav1.GetOptions{})
+func LogDeploymentAnnotationChanges(client appsclientv1.DeploymentsGetter, updated *appsv1.Deployment, ctx context.Context) {
+	existing, err := client.Deployments(updated.Namespace).Get(ctx, updated.Name, metav1.GetOptions{})
 	if err != nil {
 		klog.V(4).Infof("%v", err)
 		return
@@ -286,16 +280,11 @@ func consoleContainer(cr *operatorv1.Console, volConfigList []volumeConfig, prox
 		ImagePullPolicy: corev1.PullPolicy("IfNotPresent"),
 		Name:            api.OpenShiftConsoleName,
 		Command:         flags,
-		// TODO: can probably remove, this is used for local dev
-		//Env: []corev1.EnvVar{{
-		//	Name:  publicURLName,
-		//	Value: consoleURL(),
-		//}},
-		Env: setEnvironmentVariables(proxyConfig),
+		Env:             setEnvironmentVariables(proxyConfig),
 		Ports: []corev1.ContainerPort{{
-			Name:          consolePortName,
+			Name:          api.ConsoleContainerPortName,
 			Protocol:      corev1.ProtocolTCP,
-			ContainerPort: consolePort,
+			ContainerPort: api.ConsoleContainerTargetPort,
 		}},
 		// Delay shutdown for 25 seconds, which is the estimated time for:
 		// * endpoint propagation on delete to the router: 5s
@@ -352,7 +341,7 @@ func defaultProbe() *corev1.Probe {
 		Handler: corev1.Handler{
 			HTTPGet: &corev1.HTTPGetAction{
 				Path:   "/health",
-				Port:   intstr.FromInt(8443),
+				Port:   intstr.FromInt(api.ConsoleContainerTargetPort),
 				Scheme: corev1.URIScheme("HTTPS"),
 			},
 		},
@@ -411,7 +400,7 @@ func IsAvailableAndUpdated(deployment *appsv1.Deployment) bool {
 func defaultVolumeConfig() []volumeConfig {
 	return []volumeConfig{
 		{
-			name:     ConsoleServingCertName,
+			name:     api.ConsoleServingCertName,
 			readOnly: true,
 			path:     "/var/serving-cert",
 			isSecret: true,
